@@ -63,7 +63,7 @@ sub attract {
     my $gr  = (rand(6)/10) + .5;
     my $mode = int(rand(5));
     my $type = int(rand(7));
-    my $size = int(rand(3));
+    my $size = 1; # int(rand(3));
     $framebuffer[$Page]->cls() if ($x >= ($cls - 4) && $x <= ($cls + 4));
 
     $framebuffer[$Page]->set_color({'red' => $red,'green' => $grn,'blue' => $blu});
@@ -99,7 +99,7 @@ sub attract {
         }
         else { # This can be a large memory hog.  Disabled (random number doesn't go this high) for the moment.
             $framebuffer[$Page]->clip_set({'x' => $x-50,'y' => $y-50,'xx' => $x+50,'yy' => $y+50});
-            fill({'x' => $x,'y' => $y});
+            $framebuffer[$Page]->fill({'x' => $x,'y' => $y});
         }
     }
     $framebuffer[$Page]->clip_reset();
