@@ -72,26 +72,26 @@ devices that have accessible framebuffer devices.
 
 use strict;
 no strict 'vars'; # We have to map a variable as the screen.  So strict is
-                  # going to whine about what we do with it.
+# going to whine about what we do with it.
 use constant {
     RGB => 1,
-    BGR => 0
+      BGR => 0
 };
 use 5.010;
 # use Carp;
 use Switch;             # Yes, a touch of new Perl. Switch is so much nicer
-                        # a ton of if-else's
+# a ton of if-else's
 use Math::Trig qw(:pi); # Yes, yummy PI
 use Sys::Mmap;          # Absolutely necessary to map the screen to a string.
-                        # Without this, I doubt this module would exist.
+# Without this, I doubt this module would exist.
 use Imager;             # This is used for TrueType font printing, and where
-                        # 'Pure Perl' goes up in smoke.
+# 'Pure Perl' goes up in smoke.
 
 BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION   = 4.12;
+    our $VERSION   = 4.13;
     our @ISA       = qw(Exporter);
     our @EXPORT    = qw();
     our @EXPORT_OK = qw();
@@ -197,8 +197,8 @@ sub new {
         'FBinfo_hwaccel_copyarea'  => 'I6',     # dx(32),dy(32),width(32),height(32),sx(32),sy(32)
         'FBinfo_hwaccel_fillrect'  => 'I6',     # dx(32),dy(32),width(32),height(32),color(32),rop(32)
         'FBinfo_hwaccel_imageblit' => 'I6C1I2', # dx(32),dy(32),width(32),height(32),fg_color(32),bg_color(32),depth(8),image pointer(32),color map pointer(32)
-                                                # COLOR MAP:
-                                                #  start(32),length(32),red(16),green(16),blue(16),alpha(16)
+        # COLOR MAP:
+        #  start(32),length(32),red(16),green(16),blue(16),alpha(16)
         # Default values
         'VXRES'                    => 640,
         'VYRES'                    => 480,
@@ -239,12 +239,12 @@ sub new {
         attribute_reset($self);
 
         # Now that everything is set up, let's map the framebuffer to SCREEN
-    
+
         mmap($self->{'SCREEN'}, $self->{'smem_len'}, PROT_READ | PROT_WRITE, MAP_SHARED, $self->{'FB'});
     } else {    # Go into emulation mode if no actual framebuffer available
         # Aww bummer, no screen.  Ok, turn on emulation mode then
         $self->{'ERROR'}          = 'Framebuffer Device Not Found! Emulation mode.  EXPERIMENTAL!!';
-        
+
         # Set the resolution.  Either the defaults, or whatever the user passed in.
         $self->{'SCREEN'}         = chr(0) x ($self->{'VXRES'} * $self->{'VYRES'} * $self->{'BYTES'});
         $self->{'XRES'}           = $self->{'VXRES'}; # Virtual and physical are the same
@@ -502,8 +502,8 @@ sub plot {
     my $self   = shift;
     my $params = shift;
 
-    my $x    = int($params->{'x'}) || 0;                 # Ignore decimals
-    my $y    = int($params->{'y'}) || 0;
+    my $x    = int($params->{'x'} || 0);                 # Ignore decimals
+    my $y    = int($params->{'y'} || 0);
     my $size = int($params->{'pixel_size'} || 1);
     my ($c, $index);
 
@@ -511,35 +511,37 @@ sub plot {
         $self->circle({'x' => $x, 'y' => $y, 'radius' => ($size / 2), 'filled' => 1, 'pixel_size' => 1});
     } else {
         # Only plot if the pixel is within the clipping region
-        if (   ($x <= $self->{'XX_CLIP'})
-            && ($y <= $self->{'YY_CLIP'})
+        if (   ($x < $self->{'XX_CLIP'})
+            && ($y < $self->{'YY_CLIP'})
             && ($x >= $self->{'X_CLIP'})
             && ($y >= $self->{'Y_CLIP'})) {
-            $index = ($self->{'BYTES_PER_LINE'} * ($y + $self->{'YOFFSET'})) + ($x * $self->{'BYTES'});
-            if ($self->{'DRAW_MODE'} == $self->{'NORMAL_MODE'}) {
-                substr($self->{'SCREEN'}, $index, $self->{'BYTES'}) = $self->{'COLOR'};
-            } else {
-                $c = substr($self->{'SCREEN'}, $index, $self->{'BYTES'});
-                switch ($self->{'DRAW_MODE'}) {
-                    case ($self->{'XOR_MODE'}) {
-                        $c ^= $self->{'COLOR'};
-                    }
-                    case ($self->{'OR_MODE'}) {
-                        $c |= $self->{'COLOR'};
-                    }
-                    case ($self->{'AND_MODE'}) {
-                        $c &= $self->{'COLOR'};
-                    }
-                    case ($self->{'MASK_MODE'}) {
-                        $c = $self->{'COLOR'} if ($self->{'COLOR'} ne $self->{'B_COLOR'});
-                    }
-                    case ($self->{'UNMASK_MODE'}) {
-                        $c = $self->{'COLOR'} if ($self->pixel($x, $y) eq $self->{'B_COLOR'});
-                    }
-                } ## end switch
-                substr($self->{'SCREEN'}, $index, $self->{'BYTES'}) = $c;
-            } ## end else [ if ($self->{'DRAW_MODE'...})]
-        } ## end if (($x <= $self->{'XX_CLIP'...}))
+                $index = ($self->{'BYTES_PER_LINE'} * ($y + $self->{'YOFFSET'})) + ($x * $self->{'BYTES'});
+                if ($index >= 0 && $index <= ($self->{'smem_len'} - $self->{'BYTES'})) {
+                    if ($self->{'DRAW_MODE'} == $self->{'NORMAL_MODE'}) {
+                        substr($self->{'SCREEN'}, $index, $self->{'BYTES'}) = $self->{'COLOR'};
+                    } else {
+                        $c = substr($self->{'SCREEN'}, $index, $self->{'BYTES'});
+                        switch ($self->{'DRAW_MODE'}) {
+                            case ($self->{'XOR_MODE'}) {
+                                $c ^= $self->{'COLOR'};
+                            }
+                            case ($self->{'OR_MODE'}) {
+                                $c |= $self->{'COLOR'};
+                            }
+                            case ($self->{'AND_MODE'}) {
+                                $c &= $self->{'COLOR'};
+                            }
+                            case ($self->{'MASK_MODE'}) {
+                                $c = $self->{'COLOR'} if ($self->{'COLOR'} ne $self->{'B_COLOR'});
+                            }
+                            case ($self->{'UNMASK_MODE'}) {
+                                $c = $self->{'COLOR'} if ($self->pixel($x, $y) eq $self->{'B_COLOR'});
+                            }
+                        } ## end switch
+                        substr($self->{'SCREEN'}, $index, $self->{'BYTES'}) = $c;
+                    } ## end else [ if ($self->{'DRAW_MODE'...})]
+                }
+            } ## end if (($x <= $self->{'XX_CLIP'...}))
         $self->{'X'} = $x;
         $self->{'Y'} = $y;
     } ## end else [ if ($size > 1) ]
@@ -572,8 +574,8 @@ sub drawto {
     my $self   = shift;
     my $params = shift;
 
-    my $x_end = int($params->{'x'}) || 0;    # Ignore decimals
-    my $y_end = int($params->{'y'}) || 0;
+    my $x_end = int($params->{'x'});
+    my $y_end = int($params->{'y'});
     my $size  = int($params->{'pixel_size'} || 1);
 
     my ($width, $height);
@@ -612,16 +614,32 @@ sub drawto {
     } elsif ($y_end == $start_y) { # Draw a perfectly horizontal line (fast)
         if ($size == 1) {
             if ($start_x > $x_end) {
-                $self->blit_write({'x' => $x_end, 'y' => $y_end, 'width' => $width, 'height' => 1, 'image' => $self->{'COLOR'} x $width});    # Blitting a horizontal line is much faster!
+                if ($x_end < 0) {
+                    $self->blit_write({'x' => 0, 'y' => $y_end, 'width' => $width + $x_end, 'height' => 1, 'image' => $self->{'COLOR'} x ($width + $x_end)}) if (($width + $x_end) > 0);    # Blitting a horizontal line is much faster!
+                } else {
+                    $self->blit_write({'x' => $x_end, 'y' => $y_end, 'width' => $width, 'height' => 1, 'image' => $self->{'COLOR'} x $width});    # Blitting a horizontal line is much faster!
+                }
             } else {
-                $self->blit_write({'x' => $start_x, 'y' => $start_y, 'width' => $width, 'height' => 1, 'image' => $self->{'COLOR'} x $width});    # Blitting a horizontal line is much faster!
+                if ($start_x < 0) {
+                    $self->blit_write({'x' => 0, 'y' => $start_y, 'width' => $width + $start_x, 'height' => 1, 'image' => $self->{'COLOR'} x ($width + $start_x)}) if (($width + $start_x) > 0);    # Blitting a horizontal line is much faster!
+                } else {
+                    $self->blit_write({'x' => $start_x, 'y' => $start_y, 'width' => $width, 'height' => 1, 'image' => $self->{'COLOR'} x $width});    # Blitting a horizontal line is much faster!
+                }
             }
         } else {
             for (my $ty = ($y_end - ($size / 2)); $ty <= ($y_end + ($size / 2)); $ty++) {
                 if ($start_x > $x_end) {
-                    $self->blit_write({'x' => $x_end, 'y' => $ty, 'width' => $width, 'height' => 1, 'image' => $self->{'COLOR'} x $width});       # Blitting a horizontal line is much faster!
+                    if ($x_end < 0) {
+                        $self->blit_write({'x' => 0, 'y' => $ty, 'width' => $width + $x_end, 'height' => 1, 'image' => $self->{'COLOR'} x ($width + $x_end)}) if (($width + $x_end) > 0);       # Blitting a horizontal line is much faster!
+                    } else {
+                        $self->blit_write({'x' => $x_end, 'y' => $ty, 'width' => $width, 'height' => 1, 'image' => $self->{'COLOR'} x $width});       # Blitting a horizontal line is much faster!
+                    }
                 } else {
-                    $self->blit_write({'x' => $start_x, 'y' => $ty, 'width' => $width, 'height' => 1, 'image' => $self->{'COLOR'} x $width});     # Blitting a horizontal line is much faster!
+                    if ($start_x < 0) {
+                        $self->blit_write({'x' => 0, 'y' => $ty, 'width' => $width + $start_x, 'height' => 1, 'image' => $self->{'COLOR'} x ($width + $start_x)}) if (($width + $start_x) > 0);     # Blitting a horizontal line is much faster!
+                    } else {
+                        $self->blit_write({'x' => $start_x, 'y' => $ty, 'width' => $width, 'height' => 1, 'image' => $self->{'COLOR'} x $width});     # Blitting a horizontal line is much faster!
+                    }
                 }
             }
         }
@@ -756,15 +774,15 @@ sub draw_arc {
     my $self   = shift;
     my $params = shift;
 
-    my $x             = int($params->{'x'})      || 0;
-    my $y             = int($params->{'y'})      || 0;
-    my $radius        = int($params->{'radius'}) || 1;
+    my $x             = $params->{'x'};
+    my $y             = $params->{'y'};
+    my $radius        = int($params->{'radius'} || 1);
 
     my $start_degrees = 0 + sprintf('%.03f', $params->{'start_degrees'}) || 0;
     my $end_degrees   = 0 + sprintf('%.03f', $params->{'end_degrees'})   || 360;
     my $granularity   = 0 + sprintf('%.03f', $params->{'granularity'})   || .1;
 
-    my $mode          = int($params->{'mode'})      || 0;
+    my $mode          = int($params->{'mode'}       || 0);
     my $size          = int($params->{'pixel_size'} || 1);
     $size = 1 if ($mode == 1);
     my ($sx, $sy, $degrees, $ox, $oy) = (0,0,1,1,1);
@@ -860,14 +878,14 @@ sub ellipse {
     my $self   = shift;
     my $params = shift;
 
-    my $cx      = int($params->{'x'}) || 0;
-    my $cy      = int($params->{'y'}) || 0;
-    my $XRadius = int($params->{'xradius'}) || 1;
-    my $YRadius = int($params->{'yradius'}) || 1;
+    my $cx      = $params->{'x'};
+    my $cy      = $params->{'y'};
+    my $XRadius = int($params->{'xradius'} || 1);
+    my $YRadius = int($params->{'yradius'} || 1);
     $XRadius    = 1 if ($XRadius < 1);
     $YRadius    = 1 if ($YRadius < 1);
 
-    my $filled = int($params->{'filled'});
+    my $filled = int($params->{'filled'} || 0);
     my $fact   = $params->{'factor'}     || 1;
     my $size   = $params->{'pixel_size'} || 1;
     $size      = 1 if ($filled);
@@ -985,11 +1003,11 @@ sub circle {
     my $self   = shift;
     my $params = shift;
 
-    my $x      = int($params->{'x'});
-    my $y      = int($params->{'y'});
-    my $r      = int($params->{'radius'});
-    my $filled = int($params->{'filled'} || 0);
-    my $size   = int($params->{'pixel_size'} || 1);
+    my $x      = $params->{'x'};
+    my $y      = $params->{'y'};
+    my $r      = $params->{'radius'};
+    my $filled = $params->{'filled'};
+    my $size   = $params->{'pixel_size'};
     $self->ellipse({'x' => $x, 'y' => $y, 'xradius' => $r, 'yradius' => $r, 'filled' => $filled, 'factor' => 1, 'pixel_size' => $size});
 }
 
@@ -1022,12 +1040,12 @@ sub polygon {
 
     my $size      = int($params->{'pixel_size'} || 1);
     my @coords    = @{$params->{'coordinates'}};
-    my ($xx, $yy) = (int(shift(@coords)), int(shift(@coords)));
+    my ($xx, $yy) = (shift(@coords), shift(@coords));
     my ($x, $y);
     $self->plot({'x' => $xx, 'y' => $yy, 'pixel_size' => $size});
     while (scalar(@coords)) {
-        $x = int(shift(@coords));
-        $y = int(shift(@coords));
+        $x = shift(@coords);
+        $y = shift(@coords);
         $self->drawto({'x' => $x, 'y' => $y, 'pixel_size' => $size});
     }
     $self->drawto({'x' => $xx, 'y' => $yy, 'pixel_size' => $size});
@@ -1059,11 +1077,11 @@ sub box {
     my $self   = shift;
     my $params = shift;
 
-    my $x      = int($params->{'x'});
-    my $y      = int($params->{'y'});
-    my $xx     = int($params->{'xx'});
-    my $yy     = int($params->{'yy'});
-    my $filled = int($params->{'filled'} || 0);
+    my $x      = $params->{'x'};
+    my $y      = $params->{'y'};
+    my $xx     = $params->{'xx'};
+    my $yy     = $params->{'yy'};
+    my $filled = int($params->{'filled'}     || 0);
     my $size   = int($params->{'pixel_size'} || 1);
     $size = 1 if ($filled);
     my ($count, $data, $w, $h);
@@ -1113,12 +1131,12 @@ sub rbox {
     my $self   = shift;
     my $params = shift;
 
-    my $x      = int($params->{'x'});
-    my $y      = int($params->{'y'});
-    my $w      = int($params->{'width'});
-    my $h      = int($params->{'height'});
-    my $filled = int($params->{'filled'} || 0);
-    my $size   = int($params->{'pixel_size'} || 1);
+    my $x      = $params->{'x'};
+    my $y      = $params->{'y'};
+    my $w      = $params->{'width'};
+    my $h      = $params->{'height'};
+    my $filled = $params->{'filled'} || 0;
+    my $size   = $params->{'pixel_size'};
     $size      = 1 if ($filled);
     my $xx     = $x + $w;
     my $yy     = $y + $h;
@@ -1248,7 +1266,7 @@ sub pixel {
     } else {
         my ($color, $R, $G, $B, $A);
         my $index = ($self->{'BYTES_PER_LINE'} * ($y + $self->{'YOFFSET'})) + ($x * $self->{'BYTES'});
-        $color = substr($self->{'SCREEN'}, $index, $self->{'BYTES'});
+        $color    = substr($self->{'SCREEN'}, $index, $self->{'BYTES'});
         if ($self->{'BITS'} == 32) {
             unless($self->{'COLOR_ORDER'}) { # BGR
                 ($B, $G, $R, $A) = unpack('C4', $color);
@@ -1256,7 +1274,7 @@ sub pixel {
                 ($R, $G, $B, $A) = unpack('C4', $color);
             }
         } else {
-            $A = unpack('S', $color);
+            $A     = unpack('S', $color);
             $color = pack('S', $A);
             unless($self->{'COLOR_ORDER'}) { # BGR
                 $B     = $A & 31;
@@ -1309,8 +1327,10 @@ sub fill {
 
     my $x = int($params->{'x'});
     my $y = int($params->{'y'});
-    my ($BR, $BG, $BB, $back) = $self->pixel({'x' => $x, 'y' => $y});
-    $self->_flood({'x' => $x, 'y' => $y, 'background' => $back}) if ($back ne $self->{'COLOR'});
+    if (($x >= $self->{'X_CLIP'}) && ($x <= $self->{'XX_CLIP'}) && ($y >= $self->{'Y_CLIP'}) && ($y <= $self->{'YY_CLIP'})) {
+        my ($BR, $BG, $BB, $back) = $self->pixel({'x' => $x, 'y' => $y});
+        $self->_flood({'x' => $x, 'y' => $y, 'background' => $back}) if (defined($back) && $back ne $self->{'COLOR'});
+    }
 }
 
 sub _flood {
@@ -1324,10 +1344,11 @@ sub _flood {
     my $self   = shift;
     my $params = shift;
 
-    my $x    = int($params->{'x'});
-    my $y    = int($params->{'y'});
+    my $x    = $params->{'x'};
+    my $y    = $params->{'y'};
     my $back = $params->{'background'};
     my ($r, $g, $b, $f_color) = $self->pixel({'x' => $x, 'y' => $y});
+    return unless(defined($back) && defined($f_color));
     if (($x >= $self->{'X_CLIP'}) && ($x <= $self->{'XX_CLIP'}) && ($y >= $self->{'Y_CLIP'}) && ($y <= $self->{'YY_CLIP'}) && ($f_color eq $back)) {
         $self->plot({'x' => $x, 'y' => $y, 'pixel_size' => 1});
         # WEEEE!  Let's chow down on stack memory!!
@@ -1519,24 +1540,29 @@ sub blit_write {
     my $X_X = ($x + $self->{'XOFFSET'}) * $self->{'BYTES'};
     my ($index, $data, $px, $line, $idx, $px4);
 
-    if (   ($x >= $self->{'X_CLIP'})
-        && ($x <= $self->{'XX_CLIP'})
-        && ($y >= $self->{'Y_CLIP'})
-        && ($y <= $self->{'YY_CLIP'})) {
-        if ($x < 0) {
-            $w += $x;
-            $x = 0;
-        }
-        if ($y < 0) {
-            $scrn = substr($scrn, (abs($y) * $WW));
-            $yend += $y;
-            $y = 0;
-        }
-        $idx = 0;
-        $y    += $self->{'YOFFSET'};
-        $yend += $self->{'YOFFSET'};
-        for ($line = $y; $line < $yend; $line++) {
-            $index = ($self->{'BYTES_PER_LINE'} * $line) + $X_X;
+#    if (   ($x >= $self->{'X_CLIP'})
+#        && ($x <= $self->{'XX_CLIP'})
+#        && ($y >= $self->{'Y_CLIP'})
+#        && ($y <= $self->{'YY_CLIP'})) {
+    if ($x < 0) {
+        $w += $x;
+        $x = 0;
+        $scan += $x;
+    }
+    if ($y < 0) {
+        my $sindex = abs($y)*$WW;
+        return if ($sindex >= length($scrn));
+        $scrn = substr($scrn, (abs($y) * $WW));
+        $yend += $y;
+        $y = 0;
+    }
+    $idx = 0;
+    $y    += $self->{'YOFFSET'};
+    $yend += $self->{'YOFFSET'};
+    my $max = $self->{'smem_len'} - $self->{'BYTES'};
+    for ($line = $y; $line < $yend; $line++) {
+        $index = ($self->{'BYTES_PER_LINE'} * $line) + $X_X;
+        if ($index >= 0 && $index <= $max && $idx >=0 && $idx <= (length($scrn) - $self->{'BYTES'})) {
             switch ($self->{'DRAW_MODE'}) {
                 case ($self->{'NORMAL_MODE'}) {
                     substr($self->{'SCREEN'}, $index, $scan) = substr($scrn, $idx, $scan);
@@ -1586,8 +1612,9 @@ sub blit_write {
                 } ## end case ($self->{'UNMASK_MODE'...})
             } ## end switch
             $idx += $WW;
-        } ## end for ($line = $y; $line ...)
-    } ## end if (($x >= $self->{'X_CLIP'...}))
+        }
+    } ## end for ($line = $y; $line ...)
+    # } ## end if (($x >= $self->{'X_CLIP'...}))
 } ## end sub blit_write
 
 =head2 clip_reset
@@ -1620,8 +1647,8 @@ and ending at bottom right point xx,yy.
 =over 1
 
  $fb->clip_set({
-    'x' => 10,
-    'y' => 10,
+    'x'  => 10,
+    'y'  => 10,
     'xx' => 300,
     'yy' => 300
  });
@@ -1633,13 +1660,13 @@ sub clip_set {
     my $self   = shift;
     my $params = shift;
 
-    $self->{'X_CLIP'}  = int($params->{'x'});
-    $self->{'Y_CLIP'}  = int($params->{'y'});
-    $self->{'XX_CLIP'} = int($params->{'xx'});
-    $self->{'YY_CLIP'} = int($params->{'yy'});
+    $self->{'X_CLIP'}  = abs(int($params->{'x'}));
+    $self->{'Y_CLIP'}  = abs(int($params->{'y'}));
+    $self->{'XX_CLIP'} = abs(int($params->{'xx'}));
+    $self->{'YY_CLIP'} = abs(int($params->{'yy'}));
 
-    $self->{'X_CLIP'}  = 0                     if ($self->{'X_CLIP'} < 0);
-    $self->{'Y_CLIP'}  = 0                     if ($self->{'Y_CLIP'} < 0);
+    $self->{'X_CLIP'}  = ($self->{'XRES'} - 2) if ($self->{'X_CLIP'}  > ($self->{'XRES'} - 1));
+    $self->{'Y_CLIP'}  = ($self->{'YRES'} - 2) if ($self->{'Y_CLIP'}  > ($self->{'YRES'} - 1));
     $self->{'XX_CLIP'} = ($self->{'XRES'} - 1) if ($self->{'XX_CLIP'} >= $self->{'XRES'});
     $self->{'YY_CLIP'} = ($self->{'YRES'} - 1) if ($self->{'YY_CLIP'} >= $self->{'YRES'});
     $self->{'CLIPPED'} = 1;
@@ -1664,10 +1691,10 @@ Sets the clipping rectangle to point x,y,width,height
 sub clip_rset {
     my $self   = shift;
     my $params = shift;
-    my $x      = int($params->{'x'});
-    my $y      = int($params->{'y'});
-    my $w      = int($params->{'width'});
-    my $h      = int($params->{'height'});
+    my $x      = $params->{'x'};
+    my $y      = $params->{'y'};
+    my $w      = $params->{'width'};
+    my $h      = $params->{'height'};
 
     $self->clip_set({'x' => $x, 'y' => $y, 'xx' => ($x + $w), 'yy' => ($y + $h)});
 }
@@ -1700,8 +1727,9 @@ Bounding box mode gets the actual values needed to display the text.
 =cut
 
 sub ttf_print {
+    ##############################################################################
     # Yes, this is a "hack".                                                     #
-
+    # -------------------------------------------------------------------------- #
     # This uses the 'Imager' package.  It allocates a temporary screen buffer    #
     # and prints to it, then this buffer is dumped to the screen at the x,y      #
     # coordinates given.  Since no decent True Type packages or libraries are    #
@@ -1712,19 +1740,19 @@ sub ttf_print {
     my $self   = shift;
     my $params = shift;
 
-    my $TTF_x       = int($params->{'x'});
-    my $TTF_y       = int($params->{'y'});
-    my $TTF_w       = int($params->{'width'})  || 1;
-    my $TTF_h       = int($params->{'height'}) || 1;
+    my $TTF_x       = $params->{'x'};
+    my $TTF_y       = $params->{'y'};
+    my $TTF_w       = $params->{'width'};
+    my $TTF_h       = $params->{'height'};
     my $P_color     = $params->{'color'};
     my $text        = $params->{'text'};
     my $face        = $params->{'face'};
-    my $box_mode    = int($params->{'bounding_box'} || 0);
-    my $center_mode = int($params->{'center'} || 0);
+    my $box_mode    = $params->{'bounding_box'} || 0;
+    my $center_mode = $params->{'center'}       || 0;
     my $font_path   = $params->{'font_path'};
 
     my ($data, $font, $neg_width, $global_descent, $pos_width, $global_ascent, $descent, $ascent, $advance_width, $right_bearing);
-    $P_color = substr($P_color, 4, 2) . substr($P_color, 2, 2) . substr($P_color, 0, 2);    # T$        $P_color = Imager::Color->new("#$P_color");
+    $P_color = substr($P_color, 4, 2) . substr($P_color, 2, 2) . substr($P_color, 0, 2);
 
     eval {
         $font = Imager::Font->new(
@@ -1737,19 +1765,19 @@ sub ttf_print {
         if ($box_mode) {
             return (
                 {
-                    'x'            => $params->{'x'},
-                    'y'            => $params->{'y'},
-                    'width'        => $advance_width,
-                    'height'       => ($global_ascent - $global_descent),
-                    'color'        => $params->{'color'},
-                    'text'         => $params->{'text'},
-                    'bounding_box' => 0,
-                    'face'         => $params->{'face'},
-                    'center'       => $params->{'center'}
+                    'x'            => $TTF_x,
+                      'y'            => $TTF_y,
+                      'width'        => $advance_width,
+                      'height'       => ($global_ascent - $global_descent),
+                      'color'        => $params->{'color'},
+                      'text'         => $params->{'text'},
+                      'bounding_box' => 0,
+                      'face'         => $params->{'face'},
+                      'center'       => $params->{'center'}
                 }
             );
         } elsif ($center_mode) {
-            $TTF_x = int(($self->{'XRES'} - $advance_width) / 2);
+            $TTF_x = int(($self->{'XRES'}  - $advance_width) / 2);
             $TTF_y = int((($self->{'YRES'} - $global_ascent) / 2) + $global_ascent);
         }
         $TTF_w = $advance_width;
@@ -1780,10 +1808,15 @@ sub ttf_print {
     print STDERR $@ if ($@);
     return (
         {
-            'x'            => $TTF_x,
-            'y'            => $TTF_y - $TTF_h,
-            'width'        => $TTF_w,
-            'height'       => ($TTF_h + $global_ascent) - $global_descent
+            'color'        => $params->{'color'},
+              'text'         => $params->{'text'},
+              'bounding_box' => 0,
+              'face'         => $params->{'face'},
+              'center'       => $params->{'center'},
+              'x'            => $TTF_x,
+              'y'            => $TTF_y - $TTF_h,
+              'width'        => $TTF_w,
+              'height'       => ($TTF_h + $global_ascent) - $global_descent
         }
     );
 } ## end sub ttf_print
@@ -1842,17 +1875,17 @@ sub load_image {
     $w = int($img->getwidth());
     $h = int($img->getheight());
     if ((defined($params->{'width'}) && $params->{'width'} <=> $w) || (defined($params->{'height'}) && $params->{'height'} <=> $h)) {
-        $scale{'xpixels'} = $params->{'width'}  if (defined($params->{'width'}));
-        $scale{'ypixels'} = $params->{'height'} if (defined($params->{'height'}));
-        $scale{'type'}    = 'min';
+        $scale{'xpixels'}  = $params->{'width'}  if (defined($params->{'width'}));
+        $scale{'ypixels'}  = $params->{'height'} if (defined($params->{'height'}));
+        $scale{'type'}     = 'min';
         ($xs, $ys, $w, $h) = $img->scale_calculate(%scale);
         $w = int($w);
         $h = int($h);
 
         $img = $img->scale(%scale);
     }
-    $w = int($img->getwidth());
-    $h = int($img->getheight());
+    $w       = int($img->getwidth());
+    $h       = int($img->getheight());
     my $data = '';
     $img->write(
         'type'          => 'raw',
@@ -1884,11 +1917,11 @@ sub load_image {
     return (
         {
             'x'           => $x,
-            'y'           => $y,
-            'width'       => $w,
-            'height'      => $h,
-            'image'       => $data,
-            'orientation' => $orientation
+              'y'           => $y,
+              'width'       => $w,
+              'height'      => $h,
+              'image'       => $data,
+              'orientation' => $orientation
         }
     );
 } ## end sub load_image
@@ -1937,14 +1970,14 @@ sub RGB_to_16 {
 
     my $n_data;
     while ($big_data ne '') {
-        my $pixel_data = substr($big_data, 0, 3);
-        $big_data = substr($big_data, 3) . chr(255);
+        my $pixel_data      = substr($big_data, 0, 3);
+        $big_data           = substr($big_data, 3) . chr(255);
         my ($b, $g, $r, $a) = unpack('I', $pixel_data);
         $r = int($r / 8);
         $g = int($g / 8);
         $b = int($b / 8);
         my $color = ($r << 11) + ($g << 6) + $b;
-        $n_data .= pack('S', $color);
+        $n_data  .= pack('S', $color);
     }
     return ({'color' => $n_data});
 } ## end sub RGB_to_16
@@ -1971,14 +2004,14 @@ sub RGBA_to_16 {
 
     my $n_data;
     while ($big_data ne '') {
-        my $pixel_data = substr($big_data, 0, 4);
-        $big_data = substr($big_data, 4);
+        my $pixel_data      = substr($big_data, 0, 4);
+        $big_data           = substr($big_data, 4);
         my ($b, $g, $r, $a) = unpack('I', $pixel_data);
         $r = int($r / 8);
         $g = int($g / 8);
         $b = int($b / 8);
         my $color = ($r << 11) + ($g << 6) + $b;
-        $n_data .= pack('S', $color);
+        $n_data  .= pack('S', $color);
     }
     return ({'color' => $n_data});
 } ## end sub RGBA_to_16
@@ -2003,7 +2036,7 @@ sub RGB_to_RGBA {
     return ({'color' => $n_data});
 }
 
-## Not objects nor methods, just standard flat subroutines
+## Just standard flat subroutines
 
 sub _get_info {
     ##########################################################
@@ -2086,7 +2119,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 4.12 (July 5, 2015)
+Version 4.13 (July 6, 2015)
 
 =head1 THANKS
 
